@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: MIDI pitches for guitar chord voicings
 
-our $VERSION = '0.0609';
+our $VERSION = '0.0700';
 
 use strict;
 use warnings;
@@ -144,12 +144,36 @@ sub fingering {
 
     if (defined $variation) {
         my $fingering = $self->chords->{ 'C' . $chord_name }{fingering}[$variation];
-
         my $pitches = $self->chords->{ 'C' . $chord_name }{notes}[$variation];
-        my $diff = $target - _lowest_c($pitches);
 
-        my ($str, $pos) = split /-/, $fingering;
-        my $p = $pos + $diff;
+        my ($str, $p) = _find_fingering($target, $pitches, $fingering);
+
+        push @fingering, $str . '-' . $p if $p >= 0;
+    }
+    else {
+        for (zip $self->chords->{ 'C' . $chord_name }{notes}, $self->chords->{ 'C' . $chord_name }{fingering}) {
+            my ($pitches, $fingering) = @$_;
+
+            my ($str, $p) = _find_fingering($target, $pitches, $fingering);
+
+            push @fingering, $str . '-' . $p if $p >= 0;
+        }
+    }
+
+    return \@fingering;
+}
+
+# XXX This is overly complicated, questionable logic
+sub _find_fingering {
+    my ($target, $pitches, $fingering) = @_;
+
+    my $diff = $target - _lowest_c($pitches);
+
+    my ($str, $pos) = split /-/, $fingering;
+
+    my $p = $pos + $diff;
+
+    if ($pos != 1 && $str !~ /0/) {
         if ($p == 0 && $str !~ /0/) {
             $str = _decrement_fingering($str);
             $p++;
@@ -157,28 +181,16 @@ sub fingering {
         elsif ($p != 0 && $str =~ /0/) {
             $str = _increment_fingering($str);
         }
-        push @fingering, $str . '-' . $p;
     }
-    else {
-        for (zip $self->chords->{ 'C' . $chord_name }{notes}, $self->chords->{ 'C' . $chord_name }{fingering}) {
-            my ($pitches, $fingering) = @$_;
-            my $diff = $target - _lowest_c($pitches);
-            my ($str, $pos) = split /-/, $fingering;
-            my $p = $pos + $diff;
-            if ($p == 0 && $str !~ /0/) {
-                $str = _decrement_fingering($str);
-                $p++;
-            }
-            elsif ($p != 0 && $str =~ /0/) {
-                $str = _increment_fingering($str);
-            }
-            push @fingering, $str . '-' . $p if $p >= 0;
-        }
+    elsif ($p > 1 && $str =~ /0/) {
+        $str = _increment_fingering($str);
+        $p--;
     }
 
-    return \@fingering;
+    return $str, $p;
 }
 
+
 sub _increment_fingering {
     my ($fingering) = @_;
     my $incremented = '';
@@ -211,7 +223,7 @@ MIDI::Chord::Guitar - MIDI pitches for guitar chord voicings
 
 =head1 VERSION
 
-version 0.0609
+version 0.0700
 
 =head1 SYNOPSIS
 
@@ -242,9 +254,8 @@ voicings of an C<E A D G B E> tuned guitar.
 <img src="https://raw.githubusercontent.com/ology/MIDI-Chord-Guitar/main/guitar-position-midi-numbers.png">
 
 In order to craft a MIDI-Perl program with appropriate
-transformations, cross-reference the voicing CSV included in this
-distribution, with the diagrams above.  Check out the fingering
-column, and choose the best voicing to use.
+transformations, cross-reference the voicing CSV
+(B<voicing_file>) with the diagrams above.
 
 Alternatively, inspect the results of the C<fingering> method for each
 chord, and select those that are appropriate.
